COMPMID-417 NEON/CL MeanStdDev bugfix using FillBorderKernel

Change-Id: Ic48ba7f69783d0e1e80611264e2bc67d1732436e
Reviewed-on: http://mpd-gerrit.cambridge.arm.com/81293
Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com>
diff --git a/arm_compute/runtime/CL/functions/CLMeanStdDev.h b/arm_compute/runtime/CL/functions/CLMeanStdDev.h
index e33bcdd..7622138 100644
--- a/arm_compute/runtime/CL/functions/CLMeanStdDev.h
+++ b/arm_compute/runtime/CL/functions/CLMeanStdDev.h
@@ -25,6 +25,7 @@
 #define __ARM_COMPUTE_CLMEANSTDDEV_H__
 
 #include "arm_compute/core/CL/OpenCL.h"
+#include "arm_compute/core/CL/kernels/CLFillBorderKernel.h"
 #include "arm_compute/core/CL/kernels/CLMeanStdDevKernel.h"
 #include "arm_compute/runtime/IFunction.h"
 
@@ -38,17 +39,18 @@
     CLMeanStdDev();
     /** Initialise the kernel's inputs and outputs.
      *
      * @param[in]  input  Input image. Data types supported: U8.
      * @param[out] mean   Output average pixel value.
      * @param[out] stddev (Optional)Output standard deviation of pixel values.
      */
-    void configure(const ICLImage *input, float *mean, float *stddev = nullptr);
+    void configure(ICLImage *input, float *mean, float *stddev = nullptr);
 
     // Inherited methods overridden:
     void run() override;
 
 private:
     CLMeanStdDevKernel _mean_stddev_kernel; /**< Kernel that standard deviation calculation. */
+    CLFillBorderKernel _fill_border_kernel; /**< Kernel that fills the border with zeroes. */
     cl::Buffer         _global_sum;         /**< Variable that holds the global sum among calls in order to ease reduction */
     cl::Buffer         _global_sum_squared; /**< Variable that holds the global sum of squared values among calls in order to ease reduction */
 };
@@ -38,17 +39,18 @@
     /** Initialise the kernel's inputs and outputs.
      *
-     * @param[in]  input  Input image. Data types supported: U8.
-     * @param[out] mean   Output average pixel value.
-     * @param[out] stddev (Optional)Output standard deviation of pixel values.
+     * @param[in, out] input  Input image. Data types supported: U8. (Written to only for border filling)
+     * @param[out]     mean   Output average pixel value.
+     * @param[out]     stddev (Optional)Output standard deviation of pixel values.
      */